@@ -1,7 +1,7 @@
 package App::DateUtils;
 
 our $DATE = '2016-06-29'; # DATE
-our $VERSION = '0.07'; # VERSION
+our $VERSION = '0.08'; # VERSION
 
 use 5.010001;
 use strict;
@@ -158,13 +158,7 @@ $SPEC{parse_duration} = {
             schema  => ['str*', in=>[
                 'DateTime::Format::Alami::EN',
                 'DateTime::Format::Alami::ID',
-
-                # parsing duration with DF:Natural is not like what one would
-                # expect. it tries to find 2 dates in the text. even text like
-                # '2 days' would result in 1 date, which is the current date.
-
-                #'DateTime::Format::Natural',
-
+                'DateTime::Format::Natural',
                 'Time::Duration::Parse',
             ]],
             default => 'Time::Duration::Parse',
@@ -185,6 +179,9 @@ sub parse_duration {
     } elsif ($mod eq 'DateTime::Format::Alami::ID') {
         require DateTime::Format::Alami::ID;
         $parser = DateTime::Format::Alami::ID->new();
+    } elsif ($mod eq 'DateTime::Format::Natural') {
+        require DateTime::Format::Natural;
+        $parser = DateTime::Format::Natural->new();
     } elsif ($mod eq 'Time::Duration::Parse') {
         require Time::Duration::Parse;
     }
@@ -203,6 +200,28 @@ sub parse_duration {
             } else {
                 $rec->{is_parseable} = 0;
             }
+        } elsif ($mod =~ /^DateTime::Format::Natural/) {
+            my @dt = $parser->parse_datetime_duration($dur);
+            if (@dt > 1) {
+                require DateTime::Format::Duration::ISO8601;
+                my $dtdurf = DateTime::Format::Duration::ISO8601->new;
+                my $dtdur = $dt[1]->subtract_datetime($dt[0]);
+                $rec->{is_parseable} = 1;
+                $rec->{date1} = "$dt[0]";
+                $rec->{date2} = "$dt[1]";
+                $rec->{as_dtdur_obj} = $dtdurf->format_duration($dtdur);
+                $rec->{as_secs} =
+                    $dtdur->years * 365.25*86400 +
+                    $dtdur->months * 30.4375*86400 +
+                    $dtdur->weeks * 7*86400 +
+                    $dtdur->days * 86400 +
+                    $dtdur->hours * 3600 +
+                    $dtdur->minutes * 60 +
+                    $dtdur->seconds +
+                    $dtdur->nanoseconds * 1e-9;
+            } else {
+                $rec->{is_parseable} = 0;
+            }
         } elsif ($mod eq 'Time::Duration::Parse') {
             my $secs;
             eval { $secs = Time::Duration::Parse::parse_duration($dur) };
@@ -222,10 +241,14 @@ sub parse_duration {
 
 $SPEC{parse_duration_using_df_alami_en} = {
     v => 1.1,
-    summary => 'Parse date string(s) using DateTime::Format::Alami::EN',
+    summary => 'Parse duration string(s) using DateTime::Format::Alami::EN',
     args => {
         %durations_arg,
     },
+    examples => [
+        {args => {durations => ['2h, 3mins']}},
+        {args => {durations => ['foo']}},
+    ],
 };
 sub parse_duration_using_df_alami_en {
     my %args = @_;
@@ -234,22 +257,47 @@ sub parse_duration_using_df_alami_en {
 
 $SPEC{parse_duration_using_df_alami_id} = {
     v => 1.1,
-    summary => 'Parse date string(s) using DateTime::Format::Alami::ID',
+    summary => 'Parse duration string(s) using DateTime::Format::Alami::ID',
     args => {
         %durations_arg,
     },
+    examples => [
+        {args => {durations => ['2j, 3mnt']}},
+        {args => {durations => ['foo']}},
+    ],
 };
 sub parse_duration_using_df_alami_id {
     my %args = @_;
     parse_duration(module=>'DateTime::Format::Alami::ID', %args);
 }
 
-$SPEC{parse_duration_using_td_parse} = {
+$SPEC{parse_duration_using_df_natural} = {
     v => 1.1,
-    summary => 'Parse date string(s) using Time::Duration::Parse',
+    summary => 'Parse duration string(s) using DateTime::Format::Natural',
     args => {
         %durations_arg,
     },
+    examples => [
+        {args => {durations => ['for 2 weeks']}},
+        {args => {durations => ['from 23 Jun to 29 Jun']}},
+        {args => {durations => ['foo']}},
+    ],
+};
+sub parse_duration_using_df_natural {
+    my %args = @_;
+    parse_duration(module=>'DateTime::Format::Natural', %args);
+}
+
+$SPEC{parse_duration_using_td_parse} = {
+    v => 1.1,
+    summary => 'Parse duration string(s) using Time::Duration::Parse',
+    args => {
+        %durations_arg,
+    },
+    examples => [
+        {args => {durations => ['2 days 13 hours']}},
+        {args => {durations => ['foo']}},
+    ],
 };
 sub parse_duration_using_td_parse {
     my %args = @_;
@@ -378,7 +426,7 @@ App::DateUtils - An assortment of date-/time-related CLI utilities
 
 =head1 VERSION
 
-This document describes version 0.07 of App::DateUtils (from Perl distribution App-DateUtils), released on 2016-06-29.
+This document describes version 0.08 of App::DateUtils (from Perl distribution App-DateUtils), released on 2016-06-29.
 
 =head1 SYNOPSIS
 
@@ -405,6 +453,8 @@ date/time:
 
 =item * L<parse-duration-using-df-alami-id>
 
+=item * L<parse-duration-using-df-natural>
+
 =item * L<parse-duration-using-td-parse>
 
 =back
@@ -651,7 +701,37 @@ Return value:  (any)
 
 =head2 parse_duration_using_df_alami_en(%args) -> [status, msg, result, meta]
 
-Parse date string(s) using DateTime::Format::Alami::EN.
+Parse duration string(s) using DateTime::Format::Alami::EN.
+
+Examples:
+
+=over
+
+=item * Example #1:
+
+ parse_duration_using_df_alami_en(durations => ["2h, 3mins"]);
+
+Result:
+
+ [
+   200,
+   "OK",
+   [
+     {
+       as_dtdur_obj => "PT2H3M",
+       as_secs      => 7380,
+       is_parseable => 1,
+       original     => "2h, 3mins",
+     },
+   ],
+   {},
+ ]
+
+=item * Example #2:
+
+ parse_duration_using_df_alami_en(durations => ["foo"]); # -> [200, "OK", [{ is_parseable => 0, original => "foo" }], {}]
+
+=back
 
 This function is not exported.
 
@@ -677,7 +757,105 @@ Return value:  (any)
 
 =head2 parse_duration_using_df_alami_id(%args) -> [status, msg, result, meta]
 
-Parse date string(s) using DateTime::Format::Alami::ID.
+Parse duration string(s) using DateTime::Format::Alami::ID.
+
+Examples:
+
+=over
+
+=item * Example #1:
+
+ parse_duration_using_df_alami_id(durations => ["2j, 3mnt"]);
+
+Result:
+
+ [200, "OK", [{ is_parseable => 0, original => "2j, 3mnt" }], {}]
+
+=item * Example #2:
+
+ parse_duration_using_df_alami_id(durations => ["foo"]); # -> [200, "OK", [{ is_parseable => 0, original => "foo" }], {}]
+
+=back
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<durations>* => I<array[str]>
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
+=head2 parse_duration_using_df_natural(%args) -> [status, msg, result, meta]
+
+Parse duration string(s) using DateTime::Format::Natural.
+
+Examples:
+
+=over
+
+=item * Example #1:
+
+ parse_duration_using_df_natural(durations => ["for 2 weeks"]);
+
+Result:
+
+ [
+   200,
+   "OK",
+   [
+     {
+       as_dtdur_obj => "P2W",
+       as_secs => 1209600,
+       date1 => "2016-06-29T11:31:13",
+       date2 => "2016-07-13T11:31:13",
+       is_parseable => 1,
+       original => "for 2 weeks",
+     },
+   ],
+   {},
+ ]
+
+=item * Example #2:
+
+ parse_duration_using_df_natural(durations => ["from 23 Jun to 29 Jun"]);
+
+Result:
+
+ [
+   200,
+   "OK",
+   [
+     {
+       as_dtdur_obj => "PT11H31M13S",
+       as_secs => 41473,
+       date1 => "2016-06-29T11:31:13",
+       date2 => "2016-06-29T00:00:00",
+       is_parseable => 1,
+       original => "from 23 Jun to 29 Jun",
+     },
+   ],
+   {},
+ ]
+
+=item * Example #3:
+
+ parse_duration_using_df_natural(durations => ["foo"]); # -> [200, "OK", [{ is_parseable => 0, original => "foo" }], {}]
+
+=back
 
 This function is not exported.
 
@@ -703,7 +881,47 @@ Return value:  (any)
 
 =head2 parse_duration_using_td_parse(%args) -> [status, msg, result, meta]
 
-Parse date string(s) using Time::Duration::Parse.
+Parse duration string(s) using Time::Duration::Parse.
+
+Examples:
+
+=over
+
+=item * Example #1:
+
+ parse_duration_using_td_parse(durations => ["2 days 13 hours"]);
+
+Result:
+
+ [
+   200,
+   "OK",
+   [
+     { as_secs => 219600, is_parseable => 1, original => "2 days 13 hours" },
+   ],
+   {},
+ ]
+
+=item * Example #2:
+
+ parse_duration_using_td_parse(durations => ["foo"]);
+
+Result:
+
+ [
+   200,
+   "OK",
+   [
+     {
+       error_msg    => "Unknown timespec: foo at lib/App/DateUtils.pm line 227. ",
+       is_parseable => 0,
+       original     => "foo",
+     },
+   ],
+   {},
+ ]
+
+=back
 
 This function is not exported.
 
